@@ -1,24 +1,14 @@
-#
-#
-#  Copyright (C) 2006-2014 Andrew Speer <andrew@webdyne.org>.
-#  All rights reserved.
-#
 #  This file is part of WebDyne.
 #
-#  WebDyne is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
+#  This software is Copyright (c) 2015 by Andrew Speer <andrew@webdyne.org>.
 #
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
+#  This is free software, licensed under:
 #
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    The GNU General Public License, Version 2, June 1991
 #
+#  Full license text is available at:
+#
+#  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt>
 #
 package WebDyne;
 
@@ -64,7 +54,7 @@ use overload;
 
 #  Version information
 #
-$VERSION='1.233';
+$VERSION='1.239';
 
 
 #  Debug load
@@ -251,18 +241,31 @@ sub handler : method {
     }
 
 
-
     #  Test if compile/reload needed
     #
-    if ($self->{'_compile'} || ($cache_inode_hr->{'mtime'} < $srce_mtime) || ($cache_mtime > $cache_inode_hr->{'mtime'})) {
+    if ($WEBDYNE_RELOAD || $self->{'_compile'} || ($cache_inode_hr->{'mtime'} < $srce_mtime) || ($cache_mtime > $cache_inode_hr->{'mtime'})) {
 
 
         #  Debug
         #
-        debug("compile/reload needed _compile %s, cache_inode_hr mtime %s, srce_mtime $srce_mtime",
+        debug("compile/reload needed _compile %s, cache_inode_hr mtime %s, srce_mtime $srce_mtime, WEBDYNE::RELOAD $WEBDYNE::RELOAD",
               $self->{'_compile'}, $cache_inode_hr->{'mtime'});
 
 
+        #  use Module::Reload to reload modules
+        #
+        if ($WEBDYNE_RELOAD) {
+            local $SIG{'__DIE__'};
+            unless ($INC{'Module/Reload.pm'}) {
+                debug('loading Module::Reload');
+                eval { require Module::Reload };
+                return $self->err_html('unable to load Module::Reload - is it installed ?') if $@;
+            }
+            debug('running Module::Reload->check');
+            Module::Reload->check();
+        }
+
+
         #  Null out cache_inode to clear any flags
         #
         foreach my $key (keys %{$cache_inode_hr}) {
@@ -732,7 +735,7 @@ sub eval_cr {
    #  Return eval subroutine ref for inode ($_[0]) and eval code ref ($_[1]). Avoid using
    #  var names so not available in eval code
    #
-   eval("package WebDyne::$_[0]; $WebDyne::WEBDYNE_EVAL_USE_STRICT; sub{${$_[1]}}");
+   eval("package WebDyne::$_[0]; $WebDyne::WEBDYNE_EVAL_USE_STRICT;\n" . "#line $_[2]\n" . "sub{${$_[1]}\n}");
    
 
 }
@@ -740,7 +743,7 @@ sub eval_cr {
 
 sub perl_init_cr {
 
-    eval("package WebDyne::$_[0]; $WebDyne::WEBDYNE_EVAL_USE_STRICT; ${$_[1]}");
+   eval("package WebDyne::$_[0]; $WebDyne::WEBDYNE_EVAL_USE_STRICT;\n". "#line $_[2]\n" . "${$_[1]}");
     
 }
 
@@ -870,6 +873,7 @@ sub init_class {
         #  Debug
         #
         my $inode=$self->{'_inode'} || 'ANON'; # Anon used when no inode present, eg wdcompile
+        my $html_line_no=$data_ar->[$WEBDYNE_NODE_LINE_IX];
 
 
         #  Get CGI vars
@@ -889,23 +893,27 @@ sub init_class {
             $Package{'_cache'}{$inode}{'perl_init'}{+undef} ||= $self->perl_init();
             no strict;
             no integer;
-            &eval_cr($inode, \$eval_text) || return
-                $self->err_eval("$@", [ \$eval_text, undef, undef ]);
+            debug("calling eval sub: $eval_text");
+            &eval_cr($inode, \$eval_text, $html_line_no) || return
+                $self->err_eval("$@", \$eval_text);
         };
         #debug("eval done, eval_cr $eval_cr");
 
 
         #  Run eval
         #
-        my @eval=eval {
+        my @eval;
+        eval {
 
             #  The following line puts all CGI params in %_ during the eval so they are easy to
             #  get to ..
             local *_=$param_hr;
-            $eval_cr->($self, $eval_param_hr)
+            debug('eval call starting');
+            @eval=$eval_cr->($self, $eval_param_hr);
+            debug("eval call complete, $@, %s", Dumper(\@eval)); 
 
         };
-        if (!@eval || $@) {
+        if (!@eval || $@ || !$eval[0]) {
 
             #  An error occurred - handle it and return.
             #
@@ -913,7 +921,7 @@ sub init_class {
             
               #  Eval error or err() called during routine.
               #
-              return $self->err_eval($@ ? $@ : undef, [ \$eval_text, undef, undef ]);
+              return $self->err_eval($@ ? $@ : undef, \$eval_text);
 
             }
             else { 
@@ -995,7 +1003,7 @@ sub init_class {
             
               #  Eval error or err() called during routine.
               #
-              return $self->err_eval($@ ? $@ : undef, [ \$eval_text, undef, undef ]);
+              return $self->err_eval($@ ? $@ : undef, \$eval_text);
 
             }
             else { 
@@ -1063,7 +1071,9 @@ sub init_class {
     my $eval_code_cr=sub {
         
         my ($self, $data_ar, $eval_param_hr, $eval_text, $index, $tag_fg)=@_;
-        my $html_ar=$eval_cr->(@_) || err();
+        debug("eval code start $eval_text");
+        my $html_ar=$eval_cr->(@_) || return err();
+        debug("eval code finish %s", Dumper($html_ar));
         my $html_sr=$html_ar->[0];
         
         
@@ -1384,7 +1394,7 @@ sub render {
 
             #  Debug
             #
-            #debug("rendering webdyne tag $html_tag");
+            debug("rendering webdyne tag $html_tag");
 
 
             #  Special WebDyne tag, render using our self ref, not CGI object
@@ -2208,7 +2218,7 @@ sub perl {
             #  Error occurred. Pop data ref off stack and return
             #
             shift @{$self->{'_perl'}};
-            return $self->err_eval(undef, [ \"&${function}", 1, 1 ]);
+            return err();
 
 
         };
@@ -2346,14 +2356,9 @@ sub perl_init {
                     $self->{'_data_ar'}=\@data;
                     
                     
-                    #  Erreval array we need to pass as ref when throwing error
-                    #
-                    my @erreval=( $perl_sr, 1, undef );
-                    
-                    
                     #  Throw error
                     #
-                    return $self->err_eval($@ ? "error in __PERL__ block: $@" : undef, \@erreval);
+                    return $self->err_eval($@ ? "error in __PERL__ block: $@" : undef, $perl_sr);
 
                 }
             };
@@ -2365,7 +2370,7 @@ sub perl_init {
             
             #  Now init the perl code
             #
-            my $eval_cr=&perl_init_cr($inode, $perl_sr) || do {
+            my $eval_cr=&perl_init_cr($inode, $perl_sr, $perl_line_no) || do {
             
             
                 #  Nothing was returned from perl_init - did an error occur ?
@@ -2393,14 +2398,9 @@ sub perl_init {
                         $self->{'_data_ar'}=\@data;
                         
                         
-                        #  Erreval array we need to pass as ref when throwing error
-                        #
-                        my @erreval=( $perl_sr, 1, undef );
-                        
-                        
                         #  Throw error
                         #
-                        return $self->err_eval($@ ? "error in __PERL__ block: $@" : undef, \@erreval);
+                        return $self->err_eval($@ ? "error in __PERL__ block: $@" : undef, $perl_sr);
                             
                 }
             };
@@ -2429,7 +2429,7 @@ sub subst {
 
     #  Debug
     #
-    #debug("eval $text %s", Dumper($param_data_hr));
+    debug("eval $text %s", Dumper($param_data_hr));
 
 
     #  Get eval code refs for subst
@@ -2445,12 +2445,12 @@ sub subst {
     my $index;
     my $cr=sub { 
         my $sr=$eval_cr->{$_[0]}($self, $data_ar, $param_data_hr, $_[1], $_[2]) || 
-            return $self->err_eval(undef, [ \$_[1], 1, undef ]);
+            return err();
         (ref($sr) eq 'SCALAR') ||
             return err("eval of '$_[1]' returned %s ref, should return SCALAR ref", ref($sr));
         $sr;
     };
-    $text=~s/([\$!+*^]){1}{(\1?)(.*?)\2}/${$cr->($1,$3,$index++)}/ge;
+    $text=~s/([\$!+*^]){1}{(\1?)(.*?)\2}/${$cr->($1,$3,$index++) || return err()}/ge;
 
 
     #  Done
@@ -2471,7 +2471,7 @@ sub subst_attr {
 
     #  Debug
     #
-    #debug('subst_attr %s', Dumper({%{$attr_hr}, perl=>undef}));
+    debug('subst_attr %s', Dumper({%{$attr_hr}, perl=>undef}));
 
 
     #  Get eval code refs for subst
@@ -2495,18 +2495,20 @@ sub subst_attr {
         #  probably botch it. 
         #
         next if ($attr_name eq 'perl');
-        
 
-        #  Look for attribute value strings that need substitution
+
+        #  Look for attribute value strings that need substitution. First and second attemps did'nt work as single regexp
         #
-        if ($attr_value=~/^\s*([\$@%!+*^]){1}{(\1?)([^{]+)\2}\s*$/so ) {
+        #if ($attr_value=~/^\s*([\$@%!+*^]){1}{(\1?)([^{]+)\2}\s*$/so ) {
+        #if ($attr_value=~/^\s*([\$@%!+*^]){1}{(\1?)(.*)\2}\s*$/so ) {
+        if ($attr_value=~/^\s*([\@%!+*^]){1}{(\1?)(.*)\2}\s*$/so || $attr_value=~/^\s*(\$){1}{(\1?)([^{]+)\2}\s*$/so ) {
         
             #  Straightforward $@%!+^ operator, must be only content of value (can't be mixed
             #  with string, e.g. <popup_list values="foo=@{qw(bar)}" dont make sense
             #
             my ($oper, $eval_text)=($1,$3);
             my $eval=$eval_cr->{$oper}->($self, $data_ar, $param_hr, $eval_text, $index++, 1) ||
-                return $self->err_eval(undef, [ \$eval_text, 1, undef ]);
+                return err();
             $attr{$attr_name}=(ref($eval) eq 'SCALAR') ? ${$eval} : $eval;
 
         }
@@ -2517,12 +2519,12 @@ sub subst_attr {
             #
             my $cr=sub { 
                 my $sr=$eval_cr->{$_[0]}($self, $data_ar, $param_hr, $_[1], $_[2]) || 
-                    return $self->err_eval(undef, [ \$_[1], 1, undef ]);
+                    return err();
                 (ref($sr) eq 'SCALAR') ||
                     return err("eval of '$_[1]' returned %s ref, should return SCALAR ref", ref($sr));
                 $sr;
             };
-            $attr_value=~s/([\$!+*^]){1}{(\1?)(.*?)\2}/${$cr->($1,$3,$index++)}/ge;
+            $attr_value=~s/([\$!+*^]){1}{(\1?)(.*?)\2}/${$cr->($1,$3,$index++) || return err()}/ge;
             $attr{$attr_name}=$attr_value;
 
         }
@@ -2532,7 +2534,7 @@ sub subst_attr {
 
     #  Debug
     #
-    #debug('returning attr hash %s', Dumper({%attr, perl=>undef }));
+    debug('returning attr hash %s', Dumper({%attr, perl=>undef }));
 
 
     #  Return new attribute hash
@@ -3231,13 +3233,6 @@ sub inode {
 }
 
 
-sub perl_init_cr {
-
-    eval("package WebDyne::$_[0]; $WebDyne::WEBDYNE_EVAL_USE_STRICT; ${$_[1]}");
-    
-}
-
-
 sub data_ar {
 
 
