@@ -1,24 +1,14 @@
+#  This file is part of WebDyne.
 #
+#  This software is Copyright (c) 2015 by Andrew Speer <andrew@webdyne.org>.
 #
-#  Copyright (C) 2006-2010 Andrew Speer <andrew@webdyne.org>.
-#  All rights reserved.
+#  This is free software, licensed under:
 #
-#  This file is part of WebDyne::Cache.
+#    The GNU General Public License, Version 2, June 1991
 #
-#  WebDyne::Cache is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#  Full license text is available at:
 #
+#  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt>
 #
 package WebDyne::Cache;
 
@@ -27,6 +17,8 @@ package WebDyne::Cache;
 #
 use strict qw(vars);
 use vars   qw($VERSION);
+use warnings;
+no  warnings	qw(uninitialized);
 
 
 #  WebDyne Modules.
@@ -37,7 +29,7 @@ use WebDyne::Base;
 
 #  Version information
 #
-$VERSION='1.010';
+$VERSION='1.239';
 
 
 #  Debug 
