@@ -1,25 +1,14 @@
-#
-#
-#  Copyright (C) 2006-2010 Andrew Speer <andrew@webdyne.org>.
-#  All rights reserved.
-#
 #  This file is part of WebDyne.
 #
-#  WebDyne is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
+#  This software is Copyright (c) 2015 by Andrew Speer <andrew@webdyne.org>.
 #
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
+#  This is free software, licensed under:
 #
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    The GNU General Public License, Version 2, June 1991
 #
+#  Full license text is available at:
 #
+#  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt>
 #
 package WebDyne::Compile;
 
@@ -60,7 +49,7 @@ use WebDyne::Base;
 
 #  Version information
 #
-$VERSION='1.021';
+$VERSION='1.239';
 
 
 #  Debug load
@@ -1041,6 +1030,7 @@ sub parse {
     #
     my ($self, $html_or, $meta_hr)=@_;
     my ($line_no, $line_no_tag_end)=@{$html_or}{'_line_no', '_line_no_tag_end'};
+    my $html_fn_sr=$meta_hr->{'manifest'}[0];
     debug("parse $self, $html_or line_no $line_no line_no_tag_end $line_no_tag_end");
     #debug("parse $html_or, %s", Dumper($html_or));
 
@@ -1057,7 +1047,8 @@ sub parse {
         $WEBDYNE_NODE_LINE_TAG_END_IX,
         $WEBDYNE_NODE_SRCE_IX
     ]=(
-        undef, undef, undef, undef, $line_no, $line_no_tag_end, $meta_hr->{'manifest'}[0]
+        #undef, undef, undef, undef, $line_no, $line_no_tag_end, $meta_hr->{'manifest'}[0]
+        undef, undef, undef, undef, $line_no, $line_no_tag_end, $html_fn_sr
     );
 
 
@@ -1075,7 +1066,7 @@ sub parse {
     #  Check valid
     #
     unless (UNIVERSAL::can('CGI', $html_tag) || $CGI_TAG_WEBDYNE{$html_tag}) { 
-        return err("unknown CGI/WebDyne tag: $html_tag")
+        return err("unknown CGI/WebDyne tag: <$html_tag>, line $line_no in source file ${$html_fn_sr}")
     }
 
 
@@ -1093,7 +1084,7 @@ sub parse {
 	#
 	if ($html_or->{'_code'} && $attr{'perl'}) {
 	    push @{$meta_hr->{'perl'}}, \$attr{'perl'};
-	    push @{$meta_hr->{'perl_debug'}}, [$line_no_tag_end, $meta_hr->{'manifest'}[0]];
+	    push @{$meta_hr->{'perl_debug'}}, [$line_no, $html_fn_sr];
         }
 	else {
 	    @data[$WEBDYNE_NODE_NAME_IX, $WEBDYNE_NODE_ATTR_IX]=($html_tag, \%attr);
