@@ -1,24 +1,14 @@
-#
-#
-#  Copyright (C) 2006-2010 Andrew Speer <andrew@webdyne.org>.
-#  All rights reserved.
-#
 #  This file is part of WebDyne.
 #
-#  WebDyne is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
+#  This software is Copyright (c) 2015 by Andrew Speer <andrew@webdyne.org>.
 #
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
+#  This is free software, licensed under:
 #
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    The GNU General Public License, Version 2, June 1991
 #
+#  Full license text is available at:
+#
+#  <http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt>
 #
 package WebDyne::HTML::TreeBuilder;
 
@@ -55,7 +45,7 @@ use Data::Dumper;
 
 #  Version information
 #
-$VERSION='1.016';
+$VERSION='1.239';
 
 
 #  Debug load
@@ -536,6 +526,7 @@ sub text {
         #  Strip leading CR from Perl code so line numbers in errors make sense
         #unless ($HTML_Perl_or->{'perl'}) { $text=~s/^\n// }
 	$HTML_Perl_or->{'perl'}.=$text;
+	$HTML_Perl_or->{'_line_no_tag_end'}=$Line_no;
 
 
     }
@@ -559,7 +550,7 @@ sub text {
 	$self->implicit(0);
 	$self->push_content($HTML_Perl_or=HTML::Element->new('perl', inline=>1));
         debug("insert line_no $Line_no into object ref $HTML_Perl_or");
-	@{$HTML_Perl_or}{'_line_no', '_line_no_tag_end'}=($Line_no_start, $Line_no);
+	@{$HTML_Perl_or}{'_line_no', '_line_no_tag_end'}=($Line_no, $Line_no);
 	$HTML_Perl_or->{'_code'}++;
 
     }
@@ -593,10 +584,9 @@ sub text {
 	    }
 
 	    my $or=HTML::Element->new('subst');
-	    #$or->{'_line_no'}=$Line_no_start;
-	    $Line_no_start=$Line_no - scalar @cr;
+	    my $line_no_start=$Line_no;
             debug("insert line_no $Line_no_start, line_no_tag_end $Line_no into object ref $or for text $text, cr %s", scalar @cr);
-            @{$or}{'_line_no', '_line_no_tag_end'}=($Line_no_start, $Line_no);
+            @{$or}{'_line_no', '_line_no_tag_end'}=($line_no_start, $Line_no);
 	    $or->push_content($text);
 	    $self->tag_parse('SUPER::text', $or )
         }
